=================
Single Cell Data
=================

.. currentmodule:: glue_genes.glue_single_cell.data

.. automodule:: glue_genes.glue_single_cell.data


DataAnnData Object
-------------------

.. autosummary::
   :toctree: api/
   
   DataAnnData

DataAnnData Translator
-----------------------


.. autosummary::
   :toctree: api/

   DataAnnDataTranslator